<?php

class PerfectMoney extends PaymentModule
{
	private	$_html = '';
	private $_postErrors = array();

	public function __construct()
	{
		$this->name = 'perfectmoney';
		$this->tab = 'Payment';
		$this->version = '1.0';
		
		$this->currencies = true;
		$this->currencies_mode = 'radio';

        parent::__construct();

		$this->page = basename(__FILE__, '.php');
        $this->displayName = $this->l('Perfect Money');
        $this->description = $this->l('Accepts payments by Perfect Money');
		$this->confirmUninstall = $this->l('Are you sure you want to delete your details ?');
	}

	public function getPerfectMoneyUrl()
	{
			return 'https://perfectmoney.is/api/step1.asp';
	}

	public function install()
	{
		if (!parent::install()
			OR !Configuration::updateValue('PERFECTMONEY_ACCOUNT', 'U1234567')
			OR !Configuration::updateValue('PERFECTMONEY_NAME', 'Your Bussiness Name')
			OR !Configuration::updateValue('PERFECTMONEY_ALTERNAME', 'Set at PM')
			OR !$this->registerHook('payment')
			OR !$this->registerHook('paymentReturn'))
			return false;
		return true;
	}

	public function uninstall()
	{
		if (!Configuration::deleteByName('PERFECTMONEY_ACCOUNT')
			OR !Configuration::deleteByName('PERFECTMONEY_NAME')
			OR !Configuration::deleteByName('PERFECTMONEY_ALTERNATE')
			OR !parent::uninstall())
			return false;
		return true;
	}

	public function getContent()
	{
		$this->_html = '<h2>Perfect Money</h2>';
		if (isset($_POST['submitPerfectMoney']))
		{
			if (empty($_POST['perfectmoney_account']))
				$this->_postErrors[] = $this->l('Perfect Money USD account number is required.');
			if (empty($_POST['perfectmoney_alternate']))
				$this->_postErrors[] = $this->l('Perfect Money alternate passphrase is required. Set it at Perfect Money website.');
			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('PERFECTMONEY_ACCOUNT', strval($_POST['perfectmoney_account']));
				Configuration::updateValue('PERFECTMONEY_NAME', strval($_POST['perfectmoney_name']));
				Configuration::updateValue('PERFECTMONEY_ALTERNATE', strval($_POST['perfectmoney_alternate']));
				$this->displayConf();
			}
			else
				$this->displayErrors();
		}

		$this->displayPerfectMoney();
		$this->displayFormSettings();
		return $this->_html;
	}

	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$this->l('Settings updated').'
		</div>';
	}

	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('There are') : $this->l('There is')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('errors') : $this->l('error')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}
	
	
	public function displayPerfectMoney()
	{
		$this->_html .= '
		<div style="float: right; width: 440px; height: 150px; border: dashed 1px #666; padding: 8px; margin-left: 12px;">
			<h2>'.$this->l('Opening your Perfect Money account').'</h2>
			<div style="clear: both;"></div>
			<p>'.$this->l('By opening your Perfect Money account by clicking on the following image you are helping us significantly to develop more modules for PrestaShop and Perfect Money:').'</p>
			<p style="text-align: center;"><a href="https://perfectmoney.is/?ref=219699"><img src="../modules/perfectmoney/prestashop_perfectmoney.png" alt="PrestaShop & Perfect Money" style="margin-top: 12px;" /></a></p>
			<div style="clear: right;"></div>
		</div>
		<img src="../modules/perfectmoney/perfectmoney.gif" style="float:left; margin-right:15px;" />
		<b>'.$this->l('This module allows you to accept payments by Perfect Money.').'</b><br /><br />
		'.$this->l('If the client chooses this payment mode, your Perfect Money account will be automatically credited.').'<br />
		'.$this->l('You need to configure your Perfect Money account first before using this module.').'
		<div style="clear:both;">&nbsp;</div>';
	}

	public function displayFormSettings()
	{
		$conf = Configuration::getMultiple(array('PERFECTMONEY_ACCOUNT','PERFECTMONEY_NAME','PERFECTMONEY_ALTERNATE'));
		$perfectmoney_account = array_key_exists('perfectmoney_account', $_POST) ? $_POST['perfectmoney_account'] : (array_key_exists('PERFECTMONEY_ACCOUNT', $conf) ? $conf['PERFECTMONEY_ACCOUNT'] : '');
		$perfectmoney_name = array_key_exists('perfectmoney_name', $_POST) ? $_POST['perfectmoney_name'] : (array_key_exists('PERFECTMONEY_NAME', $conf) ? $conf['PERFECTMONEY_NAME'] : '');
		$perfectmoney_alternate = array_key_exists('perfectmoney_alternate', $_POST) ? $_POST['perfectmoney_alternate'] : (array_key_exists('PERFECTMONEY_ALTERNATE', $conf) ? $conf['PERFECTMONEY_ALTERNATE'] : '');

		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post" style="clear: both;">
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Settings').'</legend>
			<label>'.$this->l('Perfect Money USD Account').'</label>
			<div class="margin-form"><input type="text" size="33" name="perfectmoney_account" value="'.htmlentities($perfectmoney_account, ENT_COMPAT, 'UTF-8').'" /></div><br/>
			<label>'.$this->l('Merchant Name').'</label>
			<div class="margin-form"><input type="text" size="33" name="perfectmoney_name" value="'.htmlentities($perfectmoney_name, ENT_COMPAT, 'UTF-8').'" /></div><br/>
			<label>'.$this->l('Alternate Phrase').'</label>
			<div class="margin-form"><input type="text" size="33" name="perfectmoney_alternate" value="'.htmlentities($perfectmoney_alternate, ENT_COMPAT, 'UTF-8').'" /></div><br/>
			<br /><center><input type="submit" name="submitPerfectMoney" value="'.$this->l('Update settings').'" class="button" /></center>
		</fieldset>
		</form><br /><br />
		<fieldset class="width3">
			<legend><img src="../img/admin/warning.gif" />'.$this->l('Information').'</legend>
			- <b>'.$this->l('Auto Return').'</b> : '.$this->l('Off').',<br />
			- <b>'.$this->l('Payment Data Transfer').'</b> '.$this->l('to').' <b>Off</b>.<br /><br />
			'.$this->l('In').' <i>'.$this->l('Profile > Selling Preferences > Postage Calculations').'</i><br />
			- check <b>'.$this->l('Click here to allow transaction-based shipping values to override the profile shipping settings listed above').'</b><br /><br />
			<b style="color: red;">'.$this->l('All PrestaShop currencies must be also configured</b> inside Profile > Financial Information > Currency balances').'<br />
		</fieldset>';
	}

	public function hookPayment($params)
	{
		if (!$this->active)
			return ;

		global $cookie,$smarty;

		$address = new Address(intval($params['cart']->id_address_invoice));
		$customer = new Customer(intval($params['cart']->id_customer));
		$currency = $this->getCurrency();
		$perfectmoney_account = Configuration::get('PERFECTMONEY_ACCOUNT');
		$perfectmoney_name = Configuration::get('PERFECTMONEY_NAME');

		if (!Validate::isLoadedObject($address) OR !Validate::isLoadedObject($customer) OR !Validate::isLoadedObject($currency))
			return $this->l('Perfect Money error: (invalid address or customer)');
			
		$products = $params['cart']->getProducts();

		foreach ($products as $key => $product)
		{
			$products[$key]['name'] = str_replace('"', '\'', $product['name']);
			if (isset($product['attributes']))
				$products[$key]['attributes'] = str_replace('"', '\'', $product['attributes']);
			$products[$key]['name'] = htmlentities(utf8_decode($product['name']));
			$products[$key]['pmAmount'] = number_format(Tools::convertPrice($product['price_wt'], $currency), 2, '.', '');
		}

		$smarty->assign(array(
			'address' => $address,
			'country' => new Country(intval($address->id_country)),
			'customer' => $customer,
			'PAYEE_ACCOUNT' => $perfectmoney_account,
			'PAYEE_NAME' => $perfectmoney_name,
			'PAYMENT_UNITS'=>$currency->iso_code,
			'pmUrl' => $this->getPerfectMoneyUrl(),
			'PAYMENT_AMOUNT' => number_format(Tools::convertPrice($params['cart']->getOrderTotal(true, 3), $currency), 2, '.', ''),
			'PAYMENT_ID' => intval($params['cart']->id),
			'PAYMENT_URL' => 'http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/perfectmoney/validation.php',
			'NOPAYMENT_URL' => 'http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'index.php',
			'this_path' => $this->_path
		));

		return $this->display(__FILE__, 'perfectmoney.tpl');
	}

	public function hookPaymentReturn($params)
	{
		if (!$this->active)
			return ;

		return $this->display(__FILE__, 'confirmation.tpl');
	}

	function validateOrder($id_cart, $id_order_state, $amountPaid, $paymentMethod = 'Unknown', $message = NULL, $extraVars = array(), $currency_special = NULL, $dont_touch_amount = false)
	{			
		if (!$this->active)
			return ;

		$currency = $this->getCurrency();
		$cart = new Cart(intval($id_cart));
		$cart->id_currency = $currency->id;
		$cart->save();
		parent::validateOrder($id_cart, $id_order_state, $amountPaid, $paymentMethod, $message, $extraVars, $currency_special, true);
	}
}
